import QtQuick 1.0
import QtMultimediaKit 1.1

Image {
    id: container
    width: 200
    height: 220
    smooth: true
    opacity: 0.8
    source: "http://www.tagesschau.de/image/podcast/ts-140.jpg"
    MouseArea {
        anchors.bottom: parent.bottom
        width: parent.width
        height: 80
        onClicked: {
            feedModel.reload()
        }
    }

    function formatText(txt) {
        var header = "<h3>Themen</h3>"
        var rx = /^.+: /;
        var content = txt.replace(rx, "")
        return header+content.replace(/,/g,"<br/>")
    }

    function stripText(txt) {
        var rx = /^.+, /
        return txt.replace(rx, "")
    }

//    Item {
//        id: podcast
//        property string source: ""
//        signal play()
//        signal stop()
//    }

    Audio {
        id: podcast
        source: ""
    }

    XmlListModel {
        id: feedModel
        source: "http://www.tagesschau.de/export/podcast/tagesschau"
        query: "/rss/channel/item"

        XmlRole { name: "title"; query: "title/string()"; isKey: true }
        XmlRole { name: "mp3"; query: "enclosure/@url/string()" }
        XmlRole { name: "description"; query: "description/string()" }
    }


    ListView {
        id: list
        anchors.top:  parent.top
        anchors.left: parent.left
        anchors.topMargin: 5
        anchors.leftMargin: 5
        width:  parent.width
        height: 128
        spacing: 5
        model: feedModel
        delegate: Item {
            width: parent.width-10
            height: 28
            Rectangle {
                radius: 5
                anchors.fill: parent
                border {color: "#ffffff";width: 1}
                color: "transparent"
            }
            Text {
                id: titleText
                text: stripText(title)
                anchors.centerIn:  parent
                horizontalAlignment: Text.AlignHCenter
                color: "white"
                font { bold: true; pixelSize: 25 }

                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        descText.text = formatText(description);
                        podcast.source = mp3
                        desc.visible = !desc.visible
                    }
                }

            }
        }
    }
    Rectangle {
        id: desc
        anchors.fill:  parent
        visible: false
        color: "#00054b"
        Text {
            id: descText
            anchors.top:  parent.top
            anchors.horizontalCenter: parent.horizontalCenter
            width: parent.width
            height:  parent.height-play.height-10
            text: ""
            font { pixelSize: 12 }
            wrapMode: Text.WordWrap
            color:  "white"
            MouseArea {
                anchors.fill: parent
                onClicked: { desc.visible = !desc.visible }
            }
        }
        Rectangle {
            function playIt() {
                if (buttonTxt.text == "Play") {
                    buttonTxt.text = "Stop"
                    console.debug("playing")
                    podcast.play()
                } else {
                    buttonTxt.text = "Play"
                    podcast.stop()
                    console.debug("stopped")
                }
            }

            id: play
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 5
            anchors.rightMargin: 5
            anchors.right: parent.right

            border {color: "#ffffff";width: 1}
            opacity: 0.6
            width:  70
            height: 50
            radius:  5
            color: "#557eb7"
            Text {
                id: buttonTxt
                anchors.centerIn: parent
                horizontalAlignment: Text.AlignHCenter
                text: "Play"
                color:  "white"
                font { pixelSize: 15}
                MouseArea {
                    anchors.fill: parent
                    onClicked: { play.playIt() }
                }
            }
        }

    }

}
